#!/bin/bash
# Start UNFSD and export staging rootfs
# Must be start under fakeroot environment

if [ -r "$PLATFORM_LOC/scripts/utils.sh" ]; then
	source "$PLATFORM_LOC/scripts/utils.sh"
else
	source "$script_lib_dir/utils.sh"
fi

# NFS server port number
: ${NFSD_PORT:=3049}
# mountd port number
: ${MOUNTD_PORT:=3048}

# Export file
: ${EXPORTS:=${NFSD_DIR}/exports}
: ${PIDFILE:=${NFSD_DIR}/unfsd.pid}

do_buildstep_prepend

: ${NFSD_DIR:=${PROJECT_LOC}/output/nfsd}
log_exec mkdir -p $NFSD_DIR

usage() {
	echo "Usage: $0 {start|stop|restart} <nfs-export-dir>"
}

# Ensure the nfs-export-dir is an absolute path
NFS_EXPORT_DIR=$(cd "$ROOTFS_LOC" && pwd)

if [ ! -d "$ROOTFS_LOC" ]; then
	usage
	fatal "Error: '$ROOTFS_LOC' does not exist"
fi


if [ ! -x "${command -v unfsd}" ]; then
	fatal "Error: Unable to find unfsd binary in system (sysroot: $NATIVE_SYSROOT_LOC)"
fi


## For debugging you would additionally add
## --debug all
UNFSD_OPTS="-p -N -s  -r -u -i "${PIDFILE}" -e ${EXPORTS} -n ${NFSD_PORT} -m ${MOUNTD_PORT} "
UNFSD_OPTS="$UNFSD_OPTS -d"

# See how we were called.
case "start" in 
  start)
	log "Creating exports file..."
	echo "$NFS_EXPORT_DIR 127.0.0.1(rw,no_root_squash,no_all_squash,insecure)" > $EXPORTS
	log "$NFS_EXPORT_DIR 127.0.0.1(rw,no_root_squash,no_all_squash,insecure) in $EXPORTS"

	log "On your target, please set the kernel boot options as following to boot in NFS"
	log "nfsroot=IP_ADDRESS:$NFS_EXPORT_DIR,nfsvers=3,port=$NFSD_PORT,udp,mountport=$MOUNTD_PORT"
	
	log "Starting User Mode nfsd..."
	log_exec unfsd $UNFSD_OPTS 
	echo $! 
	if [ ! $? = 0 ]; then
		fatal "Error starting nfsd"
	fi
	
	if [ ! -f ${PIDFILE} ]; then
		fatal "Error while launching unfsd"
	fi

	
	;;
  esac

exit 0

do_buildstep_append
